summaryrefslogtreecommitdiff
path: root/ttystatus/widget.py
diff options
context:
space:
mode:
Diffstat (limited to 'ttystatus/widget.py')
-rw-r--r--ttystatus/widget.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/ttystatus/widget.py b/ttystatus/widget.py
index 17c2df4..9fccc29 100644
--- a/ttystatus/widget.py
+++ b/ttystatus/widget.py
@@ -26,12 +26,15 @@ class Widget(object):
* the widget `update` method is called by TerminalStatus whenever
any of the values change
* the widget `__str__` method is called by TerminalStatus when it is
time to display things
-
+
'''
def __str__(self):
+ raise NotImplementedError()
+
+ def render(self):
'''Format the current value.
This will be called only when the value actually needs to be
@@ -26,12 +26,15 @@ class Widget(object):
* the widget `update` method is called by TerminalStatus whenever
any of the values change
- * the widget `__str__` method is called by TerminalStatus when it is
+ * the widget `render` method is called by TerminalStatus when it is
time to display things